Mesa (master): st/wgl: rename stw_framebuffer_release() to stw_framebuffer_unlock()

Brian Paul brianp at kemper.freedesktop.org
Thu Nov 12 18:47:01 UTC 2015


Module: Mesa
Branch: master
Commit: 166769fe4bf4042ecb2a54ee5c7b23e3b0cd471d
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=166769fe4bf4042ecb2a54ee5c7b23e3b0cd471d

Author: Brian Paul <brianp at vmware.com>
Date:   Tue Nov 10 14:51:26 2015 -0700

st/wgl: rename stw_framebuffer_release() to stw_framebuffer_unlock()

To match the new stw_framebuffer_lock() function.

Reviewed-by: Sinclair Yeh <syeh at vmware.com>
Reviewed-by: Charmaine Lee <charmainel at vmware.com>

---

 src/gallium/state_trackers/wgl/stw_context.c     |    4 ++--
 src/gallium/state_trackers/wgl/stw_ext_pbuffer.c |    2 +-
 src/gallium/state_trackers/wgl/stw_framebuffer.c |   20 ++++++++++----------
 src/gallium/state_trackers/wgl/stw_framebuffer.h |    8 ++++----
 src/gallium/state_trackers/wgl/stw_st.c          |    4 ++--
 5 files changed, 19 insertions(+), 19 deletions(-)

diff --git a/src/gallium/state_trackers/wgl/stw_context.c b/src/gallium/state_trackers/wgl/stw_context.c
index 229fdfd..6387723 100644
--- a/src/gallium/state_trackers/wgl/stw_context.c
+++ b/src/gallium/state_trackers/wgl/stw_context.c
@@ -165,7 +165,7 @@ stw_create_context_attribs(HDC hdc, INT iLayerPlane, DHGLRC hShareContext,
    fb = stw_framebuffer_from_hdc( hdc );
    if (fb) {
       iPixelFormat = fb->iPixelFormat;
-      stw_framebuffer_release(fb);
+      stw_framebuffer_unlock(fb);
    } else {
       return 0;
    }
@@ -451,7 +451,7 @@ stw_make_current(HDC hdc, DHGLRC dhglrc)
 fail:
 
    if (fb) {
-      stw_framebuffer_release(fb);
+      stw_framebuffer_unlock(fb);
    }
 
    /* On failure, make the thread's current rendering context not current
diff --git a/src/gallium/state_trackers/wgl/stw_ext_pbuffer.c b/src/gallium/state_trackers/wgl/stw_ext_pbuffer.c
index e7887b6..c99fa3e 100644
--- a/src/gallium/state_trackers/wgl/stw_ext_pbuffer.c
+++ b/src/gallium/state_trackers/wgl/stw_ext_pbuffer.c
@@ -222,7 +222,7 @@ wglCreatePbufferARB(HDC hCurrentDC,
    fb->bPbuffer = TRUE;
    iDisplayablePixelFormat = fb->iDisplayablePixelFormat;
 
-   stw_framebuffer_release(fb);
+   stw_framebuffer_unlock(fb);
 
    /*
     * We need to set a displayable pixel format on the hidden window DC
diff --git a/src/gallium/state_trackers/wgl/stw_framebuffer.c b/src/gallium/state_trackers/wgl/stw_framebuffer.c
index a3342ab..7d7248e 100644
--- a/src/gallium/state_trackers/wgl/stw_framebuffer.c
+++ b/src/gallium/state_trackers/wgl/stw_framebuffer.c
@@ -77,7 +77,7 @@ stw_framebuffer_destroy_locked(struct stw_framebuffer *fb)
    /* check the reference count */
    fb->refcnt--;
    if (fb->refcnt) {
-      stw_framebuffer_release(fb);
+      stw_framebuffer_unlock(fb);
       return;
    }
 
@@ -95,7 +95,7 @@ stw_framebuffer_destroy_locked(struct stw_framebuffer *fb)
 
    stw_st_destroy_framebuffer_locked(fb->stfb);
 
-   stw_framebuffer_release(fb);
+   stw_framebuffer_unlock(fb);
 
    DeleteCriticalSection(&fb->mutex);
 
@@ -214,7 +214,7 @@ stw_call_window_proc(int nCode, WPARAM wParam, LPARAM lParam)
              * of the client area via GetClientRect.
              */
             stw_framebuffer_get_size(fb);
-            stw_framebuffer_release(fb);
+            stw_framebuffer_unlock(fb);
          }
       }
    }
@@ -456,7 +456,7 @@ DrvSetPixelFormat(HDC hdc, LONG iPixelFormat)
        */
       boolean bPbuffer = fb->bPbuffer;
 
-      stw_framebuffer_release( fb );
+      stw_framebuffer_unlock( fb );
 
       return bPbuffer;
    }
@@ -466,7 +466,7 @@ DrvSetPixelFormat(HDC hdc, LONG iPixelFormat)
       return FALSE;
    }
 
-   stw_framebuffer_release( fb );
+   stw_framebuffer_unlock( fb );
 
    /* Some applications mistakenly use the undocumented wglSetPixelFormat
     * function instead of SetPixelFormat, so we call SetPixelFormat here to
@@ -491,7 +491,7 @@ stw_pixelformat_get(HDC hdc)
    fb = stw_framebuffer_from_hdc(hdc);
    if (fb) {
       iPixelFormat = fb->iPixelFormat;
-      stw_framebuffer_release(fb);
+      stw_framebuffer_unlock(fb);
    }
 
    return iPixelFormat;
@@ -548,7 +548,7 @@ DrvPresentBuffers(HDC hdc, PGLPRESENTBUFFERSDATA data)
    stw_framebuffer_update(fb);
    stw_notify_current_locked(fb);
 
-   stw_framebuffer_release(fb);
+   stw_framebuffer_unlock(fb);
 
    return TRUE;
 }
@@ -577,7 +577,7 @@ stw_framebuffer_present_locked(HDC hdc,
       data.pPrivateData = (void *)res;
 
       stw_notify_current_locked(fb);
-      stw_framebuffer_release(fb);
+      stw_framebuffer_unlock(fb);
 
       return stw_dev->callbacks.wglCbPresentBuffers(hdc, &data);
    }
@@ -588,7 +588,7 @@ stw_framebuffer_present_locked(HDC hdc,
 
       stw_framebuffer_update(fb);
       stw_notify_current_locked(fb);
-      stw_framebuffer_release(fb);
+      stw_framebuffer_unlock(fb);
 
       return TRUE;
    }
@@ -609,7 +609,7 @@ DrvSwapBuffers(HDC hdc)
       return FALSE;
 
    if (!(fb->pfi->pfd.dwFlags & PFD_DOUBLEBUFFER)) {
-      stw_framebuffer_release(fb);
+      stw_framebuffer_unlock(fb);
       return TRUE;
    }
 
diff --git a/src/gallium/state_trackers/wgl/stw_st.c b/src/gallium/state_trackers/wgl/stw_st.c
index 6e5ccbb..ecf4cfc 100644
--- a/src/gallium/state_trackers/wgl/stw_st.c
+++ b/src/gallium/state_trackers/wgl/stw_st.c
@@ -149,7 +149,7 @@ stw_st_framebuffer_validate(struct st_context_iface *stctx,
       pipe_resource_reference(&out[i], stwfb->textures[statts[i]]);
    }
 
-   stw_framebuffer_release(stwfb->fb);
+   stw_framebuffer_unlock(stwfb->fb);
 
    return TRUE;
 }
@@ -170,7 +170,7 @@ stw_st_framebuffer_present_locked(HDC hdc,
       stw_framebuffer_present_locked(hdc, stwfb->fb, resource);
    }
    else {
-      stw_framebuffer_release(stwfb->fb);
+      stw_framebuffer_unlock(stwfb->fb);
    }
 
    return TRUE;




More information about the mesa-commit mailing list
diff --git a/src/gallium/state_trackers/wgl/stw_framebuffer.h b/src/gallium/state_trackers/wgl/stw_framebuffer.h
index ce9aace..109c79d 100644
--- a/src/gallium/state_trackers/wgl/stw_framebuffer.h
+++ b/src/gallium/state_trackers/wgl/stw_framebuffer.h
@@ -113,7 +113,7 @@ struct stw_framebuffer
 /**
  * Create a new framebuffer object which will correspond to the given HDC.
  * 
  * This function will acquire stw_framebuffer::mutex. stw_framebuffer_release
  * must be called when done 
  */
 struct stw_framebuffer *
@@ -126,7 +126,7 @@ stw_framebuffer_reference(struct stw_framebuffer **ptr,
 /**
  * Search a framebuffer with a matching HWND.
  * 
  * This function will acquire stw_framebuffer::mutex. stw_framebuffer_release
  * must be called when done 
  */
 struct stw_framebuffer *
@@ -135,7 +135,7 @@ stw_framebuffer_from_hwnd(HWND hwnd);
 /**
  * Search a framebuffer with a matching HDC.
  * 
  * This function will acquire stw_framebuffer::mutex. stw_framebuffer_release
  * must be called when done 
  */
 struct stw_framebuffer *
@@ -164,7 +164,7 @@ stw_framebuffer_lock(struct stw_framebuffer *fb)
  * in the meanwhile.
  */
 static inline void
-stw_framebuffer_release(struct stw_framebuffer *fb)
+stw_framebuffer_unlock(struct stw_framebuffer *fb)
 {
    assert(fb);
    LeaveCriticalSection(&fb->mutex);
@@ -113,7 +113,7 @@ struct stw_framebuffer
  * Create a new framebuffer object which will correspond to the given HDC.
  * 
- * This function will acquire stw_framebuffer::mutex. stw_framebuffer_release
+ * This function will acquire stw_framebuffer::mutex. stw_framebuffer_unlock
  * must be called when done 
  */
@@ -126,7 +126,7 @@ stw_framebuffer_reference(struct stw_framebuffer **ptr,
  * Search a framebuffer with a matching HWND.
  * 
- * This function will acquire stw_framebuffer::mutex. stw_framebuffer_release
+ * This function will acquire stw_framebuffer::mutex. stw_framebuffer_unlock
  * must be called when done 
  */
@@ -135,7 +135,7 @@ stw_framebuffer_from_hwnd(HWND hwnd);
  * Search a framebuffer with a matching HDC.
  * 
- * This function will acquire stw_framebuffer::mutex. stw_framebuffer_release
+ * This function will acquire stw_framebuffer::mutex. stw_framebuffer_unlock
  * must be called when done 
  */